# eric7.EricWidgets.EricAutoResizeTextBrowser

Module implementing a QTextBrowser widget that resizes automatically.

### Global Attributes

None

### Classes

EricAutoResizeTextBrowser | Class implementing a QTextBrowser widget that adjusts its size automatically to the contained text.

### Functions

None

## EricAutoResizeTextBrowser

Class implementing a QTextBrowser widget that adjusts its size automatically to the contained text.

### Derived from

QTextBrowser

### Class Attributes

None

### Class Methods

None

### Methods

EricAutoResizeTextBrowser | Constructor
resizeEvent | Protected method to handle resize events.
updateGeometry | Public method to update the geometry depending on the current text.

### Static Methods

None

#### EricAutoResizeTextBrowser (Constructor)

EricAutoResizeTextBrowser(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### EricAutoResizeTextBrowser.resizeEvent

resizeEvent(evt)

Protected method to handle resize events.

evt (QResizeEvent)
  reference to the resize event

#### EricAutoResizeTextBrowser.updateGeometry

updateGeometry()

Public method to update the geometry depending on the current text.

Up